@@ -179,27 +179,31 @@ class Mat4(ctypes.Structure):
         xx = x * x
         yy = y * y
         zz = z * z
+        ww = w * w
 
         xy = x * y
         yz = y * z
-        zx = z * w
+        zx = z * x
 
         wx = w * x
         wy = w * y
         wz = w * z
 
         return Mat4(
-            1-2*yy-2*xx, 2*xy+2*wz, 2*zx-2*wy, 0,
-            2*xy-2*wz, 1-2*xx-2*zz, 2*yz+2*wx, 0,
-            2*zx+2*wy, 2*yz-2*wx, 1-2*xx-2*yy, 0,
+            xx-yy-zz+ww, 2*xy+2*wz, 2*zx-2*wy, 0,
+            2*xy-2*wz, -xx+yy-zz+ww, 2*yz+2*wx, 0,
+            2*zx+2*wy, 2*yz-2*wx, -xx-yy+zz+ww, 0,
             0, 0, 0, 1
         )
-        # return Mat4(
-        #     1-2*yy-2*xx, 2*xy-2*wz, 2*zx+2*wy, 0,
-        #     2*xy+2*wz, 1-2*xx-2*zz, 2*yz-2*wx, 0 ,
-        #     2*zx-2*wy, 2*yz+2*wx, 1-2*xx-2*yy, 0,
-        #     0, 0, 0, 1
-        # )
+
+    @staticmethod
+    def new_coords(x: Float3, y: Float3, z: Float3, t: Float3):
+        return Mat4(
+            x.x, x.y, x.z, 0,
+            y.x, y.y, y.z, 0,
+            z.x, z.y, z.z, 0,
+            t.x, t.y, t.z, 1,
+        )
 
 
 class Float4(ctypes.Structure):
