@@ -11,15 +11,42 @@ from . renderer import Renderer
 logger = getLogger(__name__)
 
 
+class Scene:
+    def __init__(self) -> None:
+        self.env: List[Any] = []
+        self.drawables: List[Any] = [cube.create_cube(0.3)]
+        self.renderer = Renderer()
+        self.gizmo = gizmo.Gizmo()
+
+    def update(self, d: int):
+        for drawable in self.drawables:
+            drawable.update(d)
+
+    def draw(self, camera: ctypesmath.Camera):
+        self.gizmo.begin(camera.view.matrix, camera.projection.matrix)
+
+        for e in self.env:
+            self.renderer.draw(
+                e, camera.projection.matrix, camera.view.matrix)
+        for i, drawable in enumerate(self.drawables):
+            self.renderer.draw(
+                drawable,
+                camera.projection.matrix,
+                camera.view.matrix)
+            # aabb
+            aabb = ctypesmath.AABB.new_empty()
+            self.gizmo.aabb(drawable.expand_aabb(aabb))
+
+        self.gizmo.end()
+
+
 class SampleController(glglue.basecontroller.BaseController):
     def __init__(self):
         self.clear_color = (0.6, 0.6, 0.4, 0.0)
-        self.env: List[Any] = []
-        self.drawables: List[Any] = [cube.create_cube(0.3)]
         self.camera = ctypesmath.Camera()
-        self.isInitialized = False
-        self.renderer = Renderer()
         self.gizmo = gizmo.Gizmo()
+        self.scene = Scene()
+        self.isInitialized = False
 
     def onResize(self, w: int, h: int) -> bool:
         GL.glViewport(0, 0, w, h)
@@ -64,8 +91,8 @@ class SampleController(glglue.basecontroller.BaseController):
         '''
         milliseconds
         '''
-        for drawable in self.drawables:
-            drawable.update(d)
+        if self.scene:
+            self.scene.update(d)
         return False
 
     def initialize(self):
@@ -80,20 +107,11 @@ class SampleController(glglue.basecontroller.BaseController):
         GL.glClearColor(*self.clear_color)
         GL.glClear(GL.GL_COLOR_BUFFER_BIT |
                    GL.GL_DEPTH_BUFFER_BIT)  # type: ignore
+        if self.scene:
+            self.scene.draw(self.camera)
 
-        self.gizmo.begin(self.camera)
-
-        for e in self.env:
-            self.renderer.draw(
-                e, self.camera.projection.matrix, self.camera.view.matrix)
-        for i, drawable in enumerate(self.drawables):
-            self.renderer.draw(drawable, self.camera.projection.matrix,
-                               self.camera.view.matrix)
-            # aabb
-            aabb = ctypesmath.AABB.new_empty()
-            self.gizmo.aabb(drawable.expand_aabb(aabb))
-
+        self.gizmo.begin(self.camera.view.matrix,
+                         self.camera.projection.matrix)
         self.gizmo.axis(10)
         self.gizmo.end()
-
         GL.glFlush()
